.. automodule:: pykoala.cubing
   :members: pykoala.cubing
   :undoc-members:
   :show-inheritance:

RSS interpolation
-----------------

.. autoclass:: pykoala.cubing.InterpolationKernel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pykoala.cubing.ParabolicKernel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pykoala.cubing.GaussianKernel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pykoala.cubing.TopHatKernel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pykoala.cubing.CircularTopHatKernel
   :members:
   :undoc-members:
   :show-inheritance:


.. autoclass:: pykoala.cubing.DrizzlingKernel
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: pykoala.cubing.CubeInterpolator
   :members:
   :undoc-members:
   :show-inheritance:


Stacking
--------

.. autoclass:: pykoala.cubing.CubeStacking
   :members:
   :undoc-members:
   :show-inheritance:



Convenient functions
--------------------

.. autofunction:: pykoala.cubing.build_wcs

.. autofunction:: pykoala.cubing.build_wcs_from_rss

.. autofunction:: pykoala.cubing.make_white_image_from_array

.. autofunction:: pykoala.cubing.make_dummy_cube_from_rss


